Module batch_api

Module batch_api 

Enums

JobsApiRoutesBatchCancelBatchJobError
struct for typed errors of method jobs_api_routes_batch_cancel_batch_job
JobsApiRoutesBatchCreateBatchJobError
struct for typed errors of method jobs_api_routes_batch_create_batch_job
JobsApiRoutesBatchGetBatchJobError
struct for typed errors of method jobs_api_routes_batch_get_batch_job
JobsApiRoutesBatchGetBatchJobsError
struct for typed errors of method jobs_api_routes_batch_get_batch_jobs

Functions

jobs_api_routes_batch_cancel_batch_job
Request the cancellation of a batch job.
jobs_api_routes_batch_create_batch_job
Create a new batch job, it will be queued for processing.
jobs_api_routes_batch_get_batch_job
Get a batch job details by its UUID. Args: inline: If True, return results inline in the response.
jobs_api_routes_batch_get_batch_jobs
Get a list of batch jobs for your organization and user.