Module beta_agents_api

Module beta_agents_api 

Enums

AgentsApiV1AgentsCreateError
struct for typed errors of method agents_api_v1_agents_create
AgentsApiV1AgentsCreateOrUpdateAliasError
struct for typed errors of method agents_api_v1_agents_create_or_update_alias
AgentsApiV1AgentsDeleteAliasError
struct for typed errors of method agents_api_v1_agents_delete_alias
AgentsApiV1AgentsDeleteError
struct for typed errors of method agents_api_v1_agents_delete
AgentsApiV1AgentsGetError
struct for typed errors of method agents_api_v1_agents_get
AgentsApiV1AgentsGetVersionError
struct for typed errors of method agents_api_v1_agents_get_version
AgentsApiV1AgentsListError
struct for typed errors of method agents_api_v1_agents_list
AgentsApiV1AgentsListVersionAliasesError
struct for typed errors of method agents_api_v1_agents_list_version_aliases
AgentsApiV1AgentsListVersionsError
struct for typed errors of method agents_api_v1_agents_list_versions
AgentsApiV1AgentsUpdateError
struct for typed errors of method agents_api_v1_agents_update
AgentsApiV1AgentsUpdateVersionError
struct for typed errors of method agents_api_v1_agents_update_version

Functions

agents_api_v1_agents_create
Create a new agent giving it instructions, tools, description. The agent is then available to be used as a regular assistant in a conversation or as part of an agent pool from which it can be used.
agents_api_v1_agents_create_or_update_alias
Create a new alias or update an existing alias to point to a specific version. Aliases are unique per agent and can be reassigned to different versions.
agents_api_v1_agents_delete
agents_api_v1_agents_delete_alias
Delete an existing alias for an agent.
agents_api_v1_agents_get
Given an agent, retrieve an agent entity with its attributes. The agent_version parameter can be an integer version number or a string alias.
agents_api_v1_agents_get_version
Get a specific agent version by version number.
agents_api_v1_agents_list
Retrieve a list of agent entities sorted by creation time.
agents_api_v1_agents_list_version_aliases
Retrieve all version aliases for a specific agent.
agents_api_v1_agents_list_versions
Retrieve all versions for a specific agent with full agent context. Supports pagination.
agents_api_v1_agents_update
Update an agent attributes and create a new version.
agents_api_v1_agents_update_version
Switch the version of an agent.