Module beta_libraries_api

Module beta_libraries_api 

Enums

LibrariesCreateV1Error
struct for typed errors of method libraries_create_v1
LibrariesDeleteV1Error
struct for typed errors of method libraries_delete_v1
LibrariesGetV1Error
struct for typed errors of method libraries_get_v1
LibrariesListV1Error
struct for typed errors of method libraries_list_v1
LibrariesUpdateV1Error
struct for typed errors of method libraries_update_v1

Functions

libraries_create_v1
Create a new Library, you will be marked as the owner and only you will have the possibility to share it with others. When first created this will only be accessible by you.
libraries_delete_v1
Given a library id, deletes it together with all documents that have been uploaded to that library.
libraries_get_v1
Given a library id, details information about that Library.
libraries_list_v1
List all libraries that you have created or have been shared with you.
libraries_update_v1
Given a library id, you can update the name and description.