Module beta_libraries_documents_api

Module beta_libraries_documents_api 

Enums

LibrariesDocumentsDeleteV1Error
struct for typed errors of method libraries_documents_delete_v1
LibrariesDocumentsGetExtractedTextSignedUrlV1Error
struct for typed errors of method libraries_documents_get_extracted_text_signed_url_v1
LibrariesDocumentsGetSignedUrlV1Error
struct for typed errors of method libraries_documents_get_signed_url_v1
LibrariesDocumentsGetStatusV1Error
struct for typed errors of method libraries_documents_get_status_v1
LibrariesDocumentsGetTextContentV1Error
struct for typed errors of method libraries_documents_get_text_content_v1
LibrariesDocumentsGetV1Error
struct for typed errors of method libraries_documents_get_v1
LibrariesDocumentsListV1Error
struct for typed errors of method libraries_documents_list_v1
LibrariesDocumentsReprocessV1Error
struct for typed errors of method libraries_documents_reprocess_v1
LibrariesDocumentsUpdateV1Error
struct for typed errors of method libraries_documents_update_v1
LibrariesDocumentsUploadV1Error
struct for typed errors of method libraries_documents_upload_v1

Functions

libraries_documents_delete_v1
Given a library and a document in that library, delete that document. The document will be deleted from the library and the search index.
libraries_documents_get_extracted_text_signed_url_v1
Given a library and a document in that library, retrieve the signed URL of text extracted. For documents that are sent to the OCR this returns the result of the OCR queries.
libraries_documents_get_signed_url_v1
Given a library and a document in that library, retrieve the signed URL of a specific document.The url will expire after 30 minutes and can be accessed by anyone with the link.
libraries_documents_get_status_v1
Given a library and a document in that library, retrieve the processing status of that document.
libraries_documents_get_text_content_v1
Given a library and a document in that library, you can retrieve the text content of that document if it exists. For documents like pdf, docx and pptx the text content results from our processing using Mistral OCR.
libraries_documents_get_v1
Given a library and a document in this library, you can retrieve the metadata of that document.
libraries_documents_list_v1
Given a library, lists the document that have been uploaded to that library.
libraries_documents_reprocess_v1
Given a library and a document in that library, reprocess that document, it will be billed again.
libraries_documents_update_v1
Given a library and a document in that library, update the name of that document.
libraries_documents_upload_v1
Given a library, upload a new document to that library. It is queued for processing, it status will change it has been processed. The processing has to be completed in order be discoverable for the library search