Module files_api

Module files_api 

Enums

FilesApiRoutesDeleteFileError
struct for typed errors of method files_api_routes_delete_file
FilesApiRoutesDownloadFileError
struct for typed errors of method files_api_routes_download_file
FilesApiRoutesGetSignedUrlError
struct for typed errors of method files_api_routes_get_signed_url
FilesApiRoutesListFilesError
struct for typed errors of method files_api_routes_list_files
FilesApiRoutesRetrieveFileError
struct for typed errors of method files_api_routes_retrieve_file
FilesApiRoutesUploadFileError
struct for typed errors of method files_api_routes_upload_file

Functions

files_api_routes_delete_file
Delete a file.
files_api_routes_download_file
Download a file
files_api_routes_get_signed_url
files_api_routes_list_files
Returns a list of files that belong to the user’s organization.
files_api_routes_retrieve_file
Returns information about a specific file.
files_api_routes_upload_file
Upload a file that can be used across various endpoints. The size of individual files can be a maximum of 512 MB. The Fine-tuning API only supports .jsonl files. Please contact us if you need to increase these storage limits.