Enums
- Delete
Model V1Models Model IdDelete Error - struct for typed errors of method
delete_model_v1_models_model_id_delete - Jobs
ApiRoutes Fine Tuning Archive Fine Tuned Model Error - struct for typed errors of method
jobs_api_routes_fine_tuning_archive_fine_tuned_model - Jobs
ApiRoutes Fine Tuning Unarchive Fine Tuned Model Error - struct for typed errors of method
jobs_api_routes_fine_tuning_unarchive_fine_tuned_model - Jobs
ApiRoutes Fine Tuning Update Fine Tuned Model Error - struct for typed errors of method
jobs_api_routes_fine_tuning_update_fine_tuned_model - List
Models V1Models GetError - struct for typed errors of method
list_models_v1_models_get - Retrieve
Model V1Models Model IdGet Error - struct for typed errors of method
retrieve_model_v1_models_model_id_get
Functions
- delete_
model_ v1_ models_ model_ id_ delete - Delete a fine-tuned model.
- jobs_
api_ routes_ fine_ tuning_ archive_ fine_ tuned_ model - Archive a fine-tuned model.
- jobs_
api_ routes_ fine_ tuning_ unarchive_ fine_ tuned_ model - Un-archive a fine-tuned model.
- jobs_
api_ routes_ fine_ tuning_ update_ fine_ tuned_ model - Update a model name or description.
- list_
models_ v1_ models_ get - List all models available to the user.
- retrieve_
model_ v1_ models_ model_ id_ get - Retrieve information about a model.