pub struct Agent {Show 18 fields
pub instructions: Option<Option<String>>,
pub tools: Option<Vec<ToolsInner>>,
pub completion_args: Option<Box<CompletionArgs>>,
pub guardrails: Option<Option<Vec<GuardrailConfig>>>,
pub model: String,
pub name: String,
pub description: Option<Option<String>>,
pub handoffs: Option<Option<Vec<String>>>,
pub metadata: Option<Option<HashMap<String, Value>>>,
pub object: Option<Object>,
pub id: String,
pub version: i32,
pub versions: Vec<i32>,
pub created_at: String,
pub updated_at: String,
pub deployment_chat: bool,
pub source: String,
pub version_message: Option<Option<String>>,
}Fields
instructions: Option<Option<String>>tools: Option<Vec<ToolsInner>>List of tools which are available to the model during the conversation.
completion_args: Option<Box<CompletionArgs>>Completion arguments that will be used to generate assistant responses. Can be overridden at each message request.
guardrails: Option<Option<Vec<GuardrailConfig>>>model: Stringname: Stringdescription: Option<Option<String>>handoffs: Option<Option<Vec<String>>>metadata: Option<Option<HashMap<String, Value>>>Custom type for metadata with embedded validation.
object: Option<Object>id: Stringversion: i32versions: Vec<i32>created_at: Stringupdated_at: Stringdeployment_chat: boolsource: Stringversion_message: Option<Option<String>>Implementations