pub struct AgentUpdateRequest {
pub instructions: Option<Option<String>>,
pub tools: Option<Vec<ToolsInner>>,
pub completion_args: Option<Box<CompletionArgs>>,
pub guardrails: Option<Option<Vec<GuardrailConfig>>>,
pub model: Option<Option<String>>,
pub name: Option<Option<String>>,
pub description: Option<Option<String>>,
pub handoffs: Option<Option<Vec<String>>>,
pub deployment_chat: Option<Option<bool>>,
pub metadata: Option<Option<HashMap<String, Value>>>,
pub version_message: Option<Option<String>>,
}Fields
instructions: Option<Option<String>>tools: Option<Vec<ToolsInner>>List of tools which are available to the model during the conversation.
completion_args: Option<Box<CompletionArgs>>Completion arguments that will be used to generate assistant responses. Can be overridden at each message request.
guardrails: Option<Option<Vec<GuardrailConfig>>>model: Option<Option<String>>name: Option<Option<String>>description: Option<Option<String>>handoffs: Option<Option<Vec<String>>>deployment_chat: Option<Option<bool>>metadata: Option<Option<HashMap<String, Value>>>Custom type for metadata with embedded validation.
version_message: Option<Option<String>>Implementations
Sourceimpl AgentUpdateRequest
impl AgentUpdateRequest
pub fn new() -> AgentUpdateRequest