pub struct ClassifierTrainingParametersIn {
pub training_steps: Option<Option<i32>>,
pub learning_rate: Option<f64>,
pub weight_decay: Option<Option<f64>>,
pub warmup_fraction: Option<Option<f64>>,
pub epochs: Option<Option<f64>>,
pub seq_len: Option<Option<i32>>,
}Expand description
ClassifierTrainingParametersIn : The fine-tuning hyperparameter settings used in a classifier fine-tune job.
Fields
training_steps: Option<Option<i32>>learning_rate: Option<f64>A parameter describing how much to adjust the pre-trained model’s weights in response to the estimated error each time the weights are updated during the fine-tuning process.
weight_decay: Option<Option<f64>>warmup_fraction: Option<Option<f64>>epochs: Option<Option<f64>>seq_len: Option<Option<i32>>Implementations
Sourceimpl ClassifierTrainingParametersIn
impl ClassifierTrainingParametersIn
Sourcepub fn new() -> ClassifierTrainingParametersIn
pub fn new() -> ClassifierTrainingParametersIn
The fine-tuning hyperparameter settings used in a classifier fine-tune job.