pub struct CompletionTrainingParametersIn {
pub training_steps: Option<Option<i32>>,
pub learning_rate: Option<f64>,
pub weight_decay: Option<Option<f64>>,
pub warmup_fraction: Option<Option<f64>>,
pub epochs: Option<Option<f64>>,
pub seq_len: Option<Option<i32>>,
pub fim_ratio: Option<Option<f64>>,
}Expand description
CompletionTrainingParametersIn : The fine-tuning hyperparameter settings used in a fine-tune job.
Fields
training_steps: Option<Option<i32>>learning_rate: Option<f64>A parameter describing how much to adjust the pre-trained model’s weights in response to the estimated error each time the weights are updated during the fine-tuning process.
weight_decay: Option<Option<f64>>warmup_fraction: Option<Option<f64>>epochs: Option<Option<f64>>seq_len: Option<Option<i32>>fim_ratio: Option<Option<f64>>Implementations
Sourceimpl CompletionTrainingParametersIn
impl CompletionTrainingParametersIn
Sourcepub fn new() -> CompletionTrainingParametersIn
pub fn new() -> CompletionTrainingParametersIn
The fine-tuning hyperparameter settings used in a fine-tune job.