ConversationRestartRequest

Struct ConversationRestartRequest 

pub struct ConversationRestartRequest {
    pub inputs: Option<Box<ConversationInputs>>,
    pub stream: Option<Stream>,
    pub store: Option<bool>,
    pub handoff_execution: Option<HandoffExecution>,
    pub completion_args: Option<Box<CompletionArgs>>,
    pub guardrails: Option<Vec<GuardrailConfig>>,
    pub metadata: Option<HashMap<String, Value>>,
    pub from_entry_id: String,
    pub agent_version: Option<Option<Box<AgentVersion2>>>,
}

Fields

inputs: Option<Box<ConversationInputs>>stream: Option<Stream>store: Option<bool>

Whether to store the results into our servers or not.

handoff_execution: Option<HandoffExecution>completion_args: Option<Box<CompletionArgs>>

Completion arguments that will be used to generate assistant responses. Can be overridden at each message request.

guardrails: Option<Vec<GuardrailConfig>>metadata: Option<HashMap<String, Value>>

Custom type for metadata with embedded validation.

from_entry_id: Stringagent_version: Option<Option<Box<AgentVersion2>>>

Implementations