Module embedded_resource

Module embedded_resource 

Structs

EmbeddedResource
EmbeddedResource : The contents of a resource, embedded into a prompt or tool call result. It is up to the client how best to render embedded resources for the benefit of the LLM and/or the user.

Enums

Type