Module execution_config

Module execution_config 

Structs

ExecutionConfig
ExecutionConfig : Not typed since mcp config can changed / not stable we allow all extra fields and this is a dict TODO: once mcp is stable, we need to type this