pub struct ExecutionConfig {
pub type: String,
}Expand description
ExecutionConfig : Not typed since mcp config can changed / not stable we allow all extra fields and this is a dict TODO: once mcp is stable, we need to type this
Fields
type: StringImplementations
Sourceimpl ExecutionConfig
impl ExecutionConfig
Sourcepub fn new(type: String) -> ExecutionConfig
pub fn new(type: String) -> ExecutionConfig
Not typed since mcp config can changed / not stable we allow all extra fields and this is a dict TODO: once mcp is stable, we need to type this