pub struct ModelConversation {
pub instructions: Option<Option<String>>,
pub tools: Option<Vec<ToolsInner>>,
pub completion_args: Option<Box<CompletionArgs>>,
pub guardrails: Option<Option<Vec<GuardrailConfig>>>,
pub name: Option<Option<String>>,
pub description: Option<Option<String>>,
pub metadata: Option<Option<HashMap<String, Value>>>,
pub object: Option<Object>,
pub id: String,
pub created_at: String,
pub updated_at: String,
pub model: String,
}Fields
instructions: Option<Option<String>>tools: Option<Vec<ToolsInner>>List of tools which are available to the model during the conversation.
completion_args: Option<Box<CompletionArgs>>Completion arguments that will be used to generate assistant responses. Can be overridden at each message request.
guardrails: Option<Option<Vec<GuardrailConfig>>>name: Option<Option<String>>description: Option<Option<String>>metadata: Option<Option<HashMap<String, Value>>>Custom type for metadata with embedded validation.
object: Option<Object>id: Stringcreated_at: Stringupdated_at: Stringmodel: StringImplementations