pub struct Prediction {
pub type: Option<Type>,
pub content: Option<String>,
}Expand description
Prediction : Enable users to specify an expected completion, optimizing response times by leveraging known or predictable content.
Fields
type: Option<Type>content: Option<String>Implementations
Sourceimpl Prediction
impl Prediction
Sourcepub fn new() -> Prediction
pub fn new() -> Prediction
Enable users to specify an expected completion, optimizing response times by leveraging known or predictable content.