Module resource_link

Module resource_link 

Structs

ResourceLink
ResourceLink : A resource that the server is capable of reading, included in a prompt or tool call result. Note: resource links returned by tools are not guaranteed to appear in the results of resources/list requests.

Enums

Type