pub struct ResourceLink {
pub name: String,
pub title: Option<Option<String>>,
pub uri: String,
pub description: Option<Option<String>>,
pub mime_type: Option<Option<String>>,
pub size: Option<Option<i32>>,
pub icons: Option<Option<Vec<McpServerIcon>>>,
pub annotations: Option<Option<Annotations>>,
pub _meta: Option<Option<HashMap<String, Value>>>,
pub type: Type,
}Expand description
ResourceLink : A resource that the server is capable of reading, included in a prompt or tool call result. Note: resource links returned by tools are not guaranteed to appear in the results of resources/list requests.
Fields
name: Stringtitle: Option<Option<String>>uri: Stringdescription: Option<Option<String>>mime_type: Option<Option<String>>size: Option<Option<i32>>icons: Option<Option<Vec<McpServerIcon>>>annotations: Option<Option<Annotations>>_meta: Option<Option<HashMap<String, Value>>>type: TypeImplementations
Sourceimpl ResourceLink
impl ResourceLink