Enums
- Agents
ApiV1 Agents Create Error - struct for typed errors of method
agents_api_v1_agents_create - Agents
ApiV1 Agents Create OrUpdate Alias Error - struct for typed errors of method
agents_api_v1_agents_create_or_update_alias - Agents
ApiV1 Agents Delete Alias Error - struct for typed errors of method
agents_api_v1_agents_delete_alias - Agents
ApiV1 Agents Delete Error - struct for typed errors of method
agents_api_v1_agents_delete - Agents
ApiV1 Agents GetError - struct for typed errors of method
agents_api_v1_agents_get - Agents
ApiV1 Agents GetVersion Error - struct for typed errors of method
agents_api_v1_agents_get_version - Agents
ApiV1 Agents List Error - struct for typed errors of method
agents_api_v1_agents_list - Agents
ApiV1 Agents List Version Aliases Error - struct for typed errors of method
agents_api_v1_agents_list_version_aliases - Agents
ApiV1 Agents List Versions Error - struct for typed errors of method
agents_api_v1_agents_list_versions - Agents
ApiV1 Agents Update Error - struct for typed errors of method
agents_api_v1_agents_update - Agents
ApiV1 Agents Update Version Error - struct for typed errors of method
agents_api_v1_agents_update_version
Functions
- agents_
api_ v1_ agents_ create - Create a new agent giving it instructions, tools, description. The agent is then available to be used as a regular assistant in a conversation or as part of an agent pool from which it can be used.
- agents_
api_ v1_ agents_ create_ or_ update_ alias - Create a new alias or update an existing alias to point to a specific version. Aliases are unique per agent and can be reassigned to different versions.
- agents_
api_ v1_ agents_ delete - agents_
api_ v1_ agents_ delete_ alias - Delete an existing alias for an agent.
- agents_
api_ v1_ agents_ get - Given an agent, retrieve an agent entity with its attributes. The agent_version parameter can be an integer version number or a string alias.
- agents_
api_ v1_ agents_ get_ version - Get a specific agent version by version number.
- agents_
api_ v1_ agents_ list - Retrieve a list of agent entities sorted by creation time.
- agents_
api_ v1_ agents_ list_ version_ aliases - Retrieve all version aliases for a specific agent.
- agents_
api_ v1_ agents_ list_ versions - Retrieve all versions for a specific agent with full agent context. Supports pagination.
- agents_
api_ v1_ agents_ update - Update an agent attributes and create a new version.
- agents_
api_ v1_ agents_ update_ version - Switch the version of an agent.