Enums
- Libraries
Create V1Error - struct for typed errors of method
libraries_create_v1 - Libraries
Delete V1Error - struct for typed errors of method
libraries_delete_v1 - Libraries
GetV1 Error - struct for typed errors of method
libraries_get_v1 - Libraries
List V1Error - struct for typed errors of method
libraries_list_v1 - Libraries
Update V1Error - struct for typed errors of method
libraries_update_v1
Functions
- libraries_
create_ v1 - Create a new Library, you will be marked as the owner and only you will have the possibility to share it with others. When first created this will only be accessible by you.
- libraries_
delete_ v1 - Given a library id, deletes it together with all documents that have been uploaded to that library.
- libraries_
get_ v1 - Given a library id, details information about that Library.
- libraries_
list_ v1 - List all libraries that you have created or have been shared with you.
- libraries_
update_ v1 - Given a library id, you can update the name and description.