Enums
- Files
ApiRoutes Delete File Error - struct for typed errors of method
files_api_routes_delete_file - Files
ApiRoutes Download File Error - struct for typed errors of method
files_api_routes_download_file - Files
ApiRoutes GetSigned UrlError - struct for typed errors of method
files_api_routes_get_signed_url - Files
ApiRoutes List Files Error - struct for typed errors of method
files_api_routes_list_files - Files
ApiRoutes Retrieve File Error - struct for typed errors of method
files_api_routes_retrieve_file - Files
ApiRoutes Upload File Error - struct for typed errors of method
files_api_routes_upload_file
Functions
- files_
api_ routes_ delete_ file - Delete a file.
- files_
api_ routes_ download_ file - Download a file
- files_
api_ routes_ get_ signed_ url - files_
api_ routes_ list_ files - Returns a list of files that belong to the user’s organization.
- files_
api_ routes_ retrieve_ file - Returns information about a specific file.
- files_
api_ routes_ upload_ file - Upload a file that can be used across various endpoints. The size of individual files can be a maximum of 512 MB. The Fine-tuning API only supports .jsonl files. Please contact us if you need to increase these storage limits.