Structs
- Resource
Link - ResourceLink : A resource that the server is capable of reading, included in a prompt or tool call result. Note: resource links returned by tools are not guaranteed to appear in the results of
resources/listrequests.
resources/list requests.